#ifndef __WL_IOCTL_H__
#define __WL_IOCTL_H__

#ifdef __FreeBSD__
#  include <sys/ioctl.h>
#  include <sys/socket.h>
#  include <net/if.h>
#  include <sys/sockio.h>
#  include <sys/proc.h>
#  define   SIOC_WL_IOCTL               _IOWR('i', 60, struct ifreq)
#else
#  include <linux/if.h>
#  include <linux/sockios.h>
#  define   SIOC_WL_IOCTL               SIOCDEVPRIVATE
#endif

#include "./wlapi.h"

/*
 * WL_IOCTL_BLK is put into ifreq.ifr_data which is a union (16 bytes)
 *
 * Szeof(WL_IOCTL_BLK) must be less than 16 bteys.
 *
 * Ref: linux/if.h (Linux) and net/if.h (FreeBSD)
 */

typedef struct _WL_IOCTL_BLK {
    WORD uCmd;                /* Command to run */
    WORD uLen;                /* Length of the data buffer */
    unsigned char  *pData;              /* Pointer to the data buffer */
} WL_IOCTL_BLK, *PWL_IOCTL_BLK;

typedef struct _WL_IOCTL_PARA {
    BYTE DefaultChannel;
    BYTE Channel;
    BYTE NetworkType;
    BYTE LLCType;
    BYTE ESSID[34];
    BYTE KeepESSID[34];
    BYTE Version[2];
    BYTE FrequencyDomain;
} WL_IOCTL_PARA, *PWL_IOCTL_PARA;

#define WL_IOCTL_GET_PARAMETER   0 /* Get parameter */
#define WL_IOCTL_SET_PARAMETER   1 /* Get parameter */
#define WL_IOCTL_WRITE_FLASH     2 /* Write firmware into Flash ROM */
#define WL_IOCTL_SET_RESET       3 /* Reset the firmware */

/*
 * For not including wlapi.h, because wlu.c does not need it!
 */
struct device;  /* defined only in __KERNEL__ mode */
struct _WL_Adaptor;

int WL_Ioctl(struct device *dev, struct ifreq *rq, int cmd);
int WL_IoctlWla(struct _WL_Adaptor *pAdaptor, WL_IOCTL_BLK *pBlk, void *pDevice);

#endif /* __WL_IOCTL_H__ */
